@@ -43,13 +43,13 @@ mod sized;
 mod vec;
 mod vector;
 
-#[inline(always)]
+#[inline]
 pub const fn CV_MAT_DEPTH(flags: i32) -> i32 {
 	#![allow(non_snake_case)]
 	flags & crate::core::Mat_DEPTH_MASK
 }
 
-#[inline(always)]
+#[inline]
 pub const fn CV_MAKETYPE(depth: i32, cn: i32) -> i32 {
 	#![allow(non_snake_case)]
 	CV_MAT_DEPTH(depth) + ((cn - 1) << crate::core::CV_CN_SHIFT)
