@@ -468,26 +468,32 @@ opencv_type_enum! { crate::mcc::MCC_TYPECHART }
 pub trait ColorCorrectionModelTraitConst {
 	fn as_raw_ColorCorrectionModel(&self) -> *const c_void;
 
+	#[inline]
 	fn get_ccm(&self) -> Result<core::Mat> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_getCCM_const(self.as_raw_ColorCorrectionModel()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_loss(&self) -> Result<f64> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_getLoss_const(self.as_raw_ColorCorrectionModel()) }.into_result()
 	}
 	
+	#[inline]
 	fn get_src_rgbl(&self) -> Result<core::Mat> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_get_src_rgbl_const(self.as_raw_ColorCorrectionModel()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_dst_rgbl(&self) -> Result<core::Mat> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_get_dst_rgbl_const(self.as_raw_ColorCorrectionModel()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_mask(&self) -> Result<core::Mat> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_getMask_const(self.as_raw_ColorCorrectionModel()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_weights(&self) -> Result<core::Mat> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_getWeights_const(self.as_raw_ColorCorrectionModel()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
@@ -513,6 +519,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * cs: the absolute color space that detected colors convert to;
 	/// 
 	///           default: @ref COLOR_SPACE_sRGB
+	#[inline]
 	fn set_color_space(&mut self, cs: crate::mcc::COLOR_SPACE) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setColorSpace_COLOR_SPACE(self.as_raw_mut_ColorCorrectionModel(), cs) }.into_result()
 	}
@@ -522,6 +529,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * ccm_type: the shape of color correction matrix(CCM);
 	/// 
 	///                default: @ref CCM_3x3
+	#[inline]
 	fn set_ccm_type(&mut self, ccm_type: crate::mcc::CCM_TYPE) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setCCM_TYPE_CCM_TYPE(self.as_raw_mut_ColorCorrectionModel(), ccm_type) }.into_result()
 	}
@@ -531,6 +539,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * distance: the type of color distance;
 	/// 
 	///                default: @ref DISTANCE_CIE2000
+	#[inline]
 	fn set_distance(&mut self, distance: crate::mcc::DISTANCE_TYPE) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setDistance_DISTANCE_TYPE(self.as_raw_mut_ColorCorrectionModel(), distance) }.into_result()
 	}
@@ -540,6 +549,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * linear_type: the method of linearization;
 	/// 
 	///                   default: @ref LINEARIZATION_GAMMA
+	#[inline]
 	fn set_linear(&mut self, linear_type: crate::mcc::LINEAR_TYPE) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setLinear_LINEAR_TYPE(self.as_raw_mut_ColorCorrectionModel(), linear_type) }.into_result()
 	}
@@ -554,6 +564,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * gamma: the gamma value of gamma correction;
 	/// 
 	///              default: 2.2;
+	#[inline]
 	fn set_linear_gamma(&mut self, gamma: &f64) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setLinearGamma_const_doubleR(self.as_raw_mut_ColorCorrectionModel(), gamma) }.into_result()
 	}
@@ -570,6 +581,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * deg: the degree of linearization polynomial;
 	/// 
 	///        default: 3
+	#[inline]
 	fn set_linear_degree(&mut self, deg: &i32) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setLinearDegree_const_intR(self.as_raw_mut_ColorCorrectionModel(), deg) }.into_result()
 	}
@@ -584,6 +596,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * upper: the upper threshold to determine saturation;
 	/// 
 	///              default: 0
+	#[inline]
 	fn set_saturated_threshold(&mut self, lower: &f64, upper: &f64) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setSaturatedThreshold_const_doubleR_const_doubleR(self.as_raw_mut_ColorCorrectionModel(), lower, upper) }.into_result()
 	}
@@ -593,6 +606,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * weights_list: the list of weight of each color;
 	/// 
 	///                    default: empty array
+	#[inline]
 	fn set_weights_list(&mut self, weights_list: &core::Mat) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setWeightsList_const_MatR(self.as_raw_mut_ColorCorrectionModel(), weights_list.as_raw_Mat()) }.into_result()
 	}
@@ -602,6 +616,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * weights_coeff: the exponent number of L* component of the reference color in CIE Lab color space;
 	/// 
 	///                      default: 0
+	#[inline]
 	fn set_weight_coeff(&mut self, weights_coeff: &f64) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setWeightCoeff_const_doubleR(self.as_raw_mut_ColorCorrectionModel(), weights_coeff) }.into_result()
 	}
@@ -611,6 +626,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// * initial_method_type: the method of calculating CCM initial value;
 	/// 
 	///        default: INITIAL_METHOD_LEAST_SQUARE
+	#[inline]
 	fn set_initial_method(&mut self, initial_method_type: crate::mcc::INITIAL_METHOD_TYPE) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setInitialMethod_INITIAL_METHOD_TYPE(self.as_raw_mut_ColorCorrectionModel(), initial_method_type) }.into_result()
 	}
@@ -622,6 +638,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	///    Terminal criteria to the algorithm;
 	/// 
 	///                  default: 5000;
+	#[inline]
 	fn set_max_count(&mut self, max_count: &i32) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setMaxCount_const_intR(self.as_raw_mut_ColorCorrectionModel(), max_count) }.into_result()
 	}
@@ -633,11 +650,13 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	///    Terminal criteria to the algorithm;
 	/// 
 	///               default: 1e-4;
+	#[inline]
 	fn set_epsilon(&mut self, epsilon: &f64) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_setEpsilon_const_doubleR(self.as_raw_mut_ColorCorrectionModel(), epsilon) }.into_result()
 	}
 	
 	/// make color correction
+	#[inline]
 	fn run(&mut self) -> Result<()> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_run(self.as_raw_mut_ColorCorrectionModel()) }.into_result()
 	}
@@ -651,6 +670,7 @@ pub trait ColorCorrectionModelTrait: crate::mcc::ColorCorrectionModelTraitConst
 	/// 
 	/// ## C++ default parameters
 	/// * islinear: false
+	#[inline]
 	fn infer(&mut self, img: &core::Mat, islinear: bool) -> Result<core::Mat> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_infer_const_MatR_bool(self.as_raw_mut_ColorCorrectionModel(), img.as_raw_Mat(), islinear) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
@@ -696,6 +716,7 @@ impl ColorCorrectionModel {
 	/// 
 	///            the color type is RGB not BGR, and the color values are in [0, 1];
 	/// * constcolor: the Built-in color card
+	#[inline]
 	pub fn new(src: &core::Mat, constcolor: crate::mcc::CONST_COLOR) -> Result<crate::mcc::ColorCorrectionModel> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_ColorCorrectionModel_const_MatR_CONST_COLOR(src.as_raw_Mat(), constcolor) }.into_result().map(|r| unsafe { crate::mcc::ColorCorrectionModel::opencv_from_extern(r) } )
 	}
@@ -710,6 +731,7 @@ impl ColorCorrectionModel {
 	/// * ref_cs: the corresponding color space
 	///            If the color type is some RGB, the format is RGB not BGR;
 	/// 
+	#[inline]
 	pub fn new_1(src: &core::Mat, mut colors: core::Mat, ref_cs: crate::mcc::COLOR_SPACE) -> Result<crate::mcc::ColorCorrectionModel> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_ColorCorrectionModel_const_MatR_Mat_COLOR_SPACE(src.as_raw_Mat(), colors.as_raw_mut_Mat(), ref_cs) }.into_result().map(|r| unsafe { crate::mcc::ColorCorrectionModel::opencv_from_extern(r) } )
 	}
@@ -723,6 +745,7 @@ impl ColorCorrectionModel {
 	/// * ref_cs: the corresponding color space
 	///            If the color type is some RGB, the format is RGB not BGR;
 	/// * colored: mask of colored color
+	#[inline]
 	pub fn new_2(src: &core::Mat, mut colors: core::Mat, ref_cs: crate::mcc::COLOR_SPACE, mut colored: core::Mat) -> Result<crate::mcc::ColorCorrectionModel> {
 		unsafe { sys::cv_ccm_ColorCorrectionModel_ColorCorrectionModel_const_MatR_Mat_COLOR_SPACE_Mat(src.as_raw_Mat(), colors.as_raw_mut_Mat(), ref_cs, colored.as_raw_mut_Mat()) }.into_result().map(|r| unsafe { crate::mcc::ColorCorrectionModel::opencv_from_extern(r) } )
 	}
@@ -744,50 +767,62 @@ pub trait MCC_CCheckerConst {
 pub trait MCC_CChecker: crate::mcc::MCC_CCheckerConst {
 	fn as_raw_mut_MCC_CChecker(&mut self) -> *mut c_void;
 
+	#[inline]
 	fn set_target(&mut self, _target: crate::mcc::MCC_TYPECHART) -> Result<()> {
 		unsafe { sys::cv_mcc_CChecker_setTarget_TYPECHART(self.as_raw_mut_MCC_CChecker(), _target) }.into_result()
 	}
 	
+	#[inline]
 	fn set_box(&mut self, mut _box: core::Vector<core::Point2f>) -> Result<()> {
 		unsafe { sys::cv_mcc_CChecker_setBox_vector_Point2f_(self.as_raw_mut_MCC_CChecker(), _box.as_raw_mut_VectorOfPoint2f()) }.into_result()
 	}
 	
+	#[inline]
 	fn set_charts_rgb(&mut self, mut _charts_rgb: core::Mat) -> Result<()> {
 		unsafe { sys::cv_mcc_CChecker_setChartsRGB_Mat(self.as_raw_mut_MCC_CChecker(), _charts_rgb.as_raw_mut_Mat()) }.into_result()
 	}
 	
+	#[inline]
 	fn set_charts_y_cb_cr(&mut self, mut _charts_y_cb_cr: core::Mat) -> Result<()> {
 		unsafe { sys::cv_mcc_CChecker_setChartsYCbCr_Mat(self.as_raw_mut_MCC_CChecker(), _charts_y_cb_cr.as_raw_mut_Mat()) }.into_result()
 	}
 	
+	#[inline]
 	fn set_cost(&mut self, _cost: f32) -> Result<()> {
 		unsafe { sys::cv_mcc_CChecker_setCost_float(self.as_raw_mut_MCC_CChecker(), _cost) }.into_result()
 	}
 	
+	#[inline]
 	fn set_center(&mut self, _center: core::Point2f) -> Result<()> {
 		unsafe { sys::cv_mcc_CChecker_setCenter_Point2f(self.as_raw_mut_MCC_CChecker(), _center.opencv_as_extern()) }.into_result()
 	}
 	
+	#[inline]
 	fn get_target(&mut self) -> Result<crate::mcc::MCC_TYPECHART> {
 		unsafe { sys::cv_mcc_CChecker_getTarget(self.as_raw_mut_MCC_CChecker()) }.into_result()
 	}
 	
+	#[inline]
 	fn get_box(&mut self) -> Result<core::Vector<core::Point2f>> {
 		unsafe { sys::cv_mcc_CChecker_getBox(self.as_raw_mut_MCC_CChecker()) }.into_result().map(|r| unsafe { core::Vector::<core::Point2f>::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_charts_rgb(&mut self) -> Result<core::Mat> {
 		unsafe { sys::cv_mcc_CChecker_getChartsRGB(self.as_raw_mut_MCC_CChecker()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_charts_y_cb_cr(&mut self) -> Result<core::Mat> {
 		unsafe { sys::cv_mcc_CChecker_getChartsYCbCr(self.as_raw_mut_MCC_CChecker()) }.into_result().map(|r| unsafe { core::Mat::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	fn get_cost(&mut self) -> Result<f32> {
 		unsafe { sys::cv_mcc_CChecker_getCost(self.as_raw_mut_MCC_CChecker()) }.into_result()
 	}
 	
+	#[inline]
 	fn get_center(&mut self) -> Result<core::Point2f> {
 		unsafe { sys::cv_mcc_CChecker_getCenter(self.as_raw_mut_MCC_CChecker()) }.into_result()
 	}
@@ -797,6 +832,7 @@ pub trait MCC_CChecker: crate::mcc::MCC_CCheckerConst {
 impl dyn MCC_CChecker + '_ {
 	/// \brief Create a new CChecker object.
 	/// \return A pointer to the implementation of the CChecker
+	#[inline]
 	pub fn create() -> Result<core::Ptr<dyn crate::mcc::MCC_CChecker>> {
 		unsafe { sys::cv_mcc_CChecker_create() }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::mcc::MCC_CChecker>::opencv_from_extern(r) } )
 	}
@@ -821,6 +857,7 @@ pub trait MCC_CCheckerDetector: core::AlgorithmTrait + crate::mcc::MCC_CCheckerD
 	///            the function will return false.
 	/// \return true if it was able to set the detector's network,
 	///        false otherwise.
+	#[inline]
 	fn set_net(&mut self, mut net: crate::dnn::Net) -> Result<bool> {
 		unsafe { sys::cv_mcc_CCheckerDetector_setNet_Net(self.as_raw_mut_MCC_CCheckerDetector(), net.as_raw_mut_Net()) }.into_result()
 	}
@@ -848,6 +885,7 @@ pub trait MCC_CCheckerDetector: core::AlgorithmTrait + crate::mcc::MCC_CCheckerD
 	/// * nc: 1
 	/// * use_net: false
 	/// * params: DetectorParameters::create()
+	#[inline]
 	fn process_with_roi(&mut self, image: &dyn core::ToInputArray, chart_type: crate::mcc::MCC_TYPECHART, regions_of_interest: &core::Vector<core::Rect>, nc: i32, use_net: bool, params: &core::Ptr<crate::mcc::MCC_DetectorParameters>) -> Result<bool> {
 		input_array_arg!(image);
 		unsafe { sys::cv_mcc_CCheckerDetector_process_const__InputArrayR_const_TYPECHART_const_vector_Rect_R_const_int_bool_const_Ptr_DetectorParameters_R(self.as_raw_mut_MCC_CCheckerDetector(), image.as_raw__InputArray(), chart_type, regions_of_interest.as_raw_VectorOfRect(), nc, use_net, params.as_raw_PtrOfMCC_DetectorParameters()) }.into_result()
@@ -877,6 +915,7 @@ pub trait MCC_CCheckerDetector: core::AlgorithmTrait + crate::mcc::MCC_CCheckerD
 	/// * nc: 1
 	/// * use_net: false
 	/// * params: DetectorParameters::create()
+	#[inline]
 	fn process(&mut self, image: &dyn core::ToInputArray, chart_type: crate::mcc::MCC_TYPECHART, nc: i32, use_net: bool, params: &core::Ptr<crate::mcc::MCC_DetectorParameters>) -> Result<bool> {
 		input_array_arg!(image);
 		unsafe { sys::cv_mcc_CCheckerDetector_process_const__InputArrayR_const_TYPECHART_const_int_bool_const_Ptr_DetectorParameters_R(self.as_raw_mut_MCC_CCheckerDetector(), image.as_raw__InputArray(), chart_type, nc, use_net, params.as_raw_PtrOfMCC_DetectorParameters()) }.into_result()
@@ -886,12 +925,14 @@ pub trait MCC_CCheckerDetector: core::AlgorithmTrait + crate::mcc::MCC_CCheckerD
 	///        detected with the highest confidence.
 	/// \return checker A single colorchecker, if atleast one colorchecker
 	///                was detected, 'nullptr' otherwise.
+	#[inline]
 	fn get_best_color_checker(&mut self) -> Result<core::Ptr<dyn crate::mcc::MCC_CChecker>> {
 		unsafe { sys::cv_mcc_CCheckerDetector_getBestColorChecker(self.as_raw_mut_MCC_CCheckerDetector()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::mcc::MCC_CChecker>::opencv_from_extern(r) } )
 	}
 	
 	/// \brief Get the list of all detected colorcheckers
 	/// \return checkers vector of colorcheckers
+	#[inline]
 	fn get_list_color_checker(&mut self) -> Result<core::Vector<core::Ptr<dyn crate::mcc::MCC_CChecker>>> {
 		unsafe { sys::cv_mcc_CCheckerDetector_getListColorChecker(self.as_raw_mut_MCC_CCheckerDetector()) }.into_result().map(|r| unsafe { core::Vector::<core::Ptr<dyn crate::mcc::MCC_CChecker>>::opencv_from_extern(r) } )
 	}
@@ -900,6 +941,7 @@ pub trait MCC_CCheckerDetector: core::AlgorithmTrait + crate::mcc::MCC_CCheckerD
 
 impl dyn MCC_CCheckerDetector + '_ {
 	/// \brief Returns the implementation of the CCheckerDetector.
+	#[inline]
 	pub fn create() -> Result<core::Ptr<dyn crate::mcc::MCC_CCheckerDetector>> {
 		unsafe { sys::cv_mcc_CCheckerDetector_create() }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::mcc::MCC_CCheckerDetector>::opencv_from_extern(r) } )
 	}
@@ -929,6 +971,7 @@ pub trait MCC_CCheckerDraw: crate::mcc::MCC_CCheckerDrawConst {
 	/// \brief Draws the checker to the given image.
 	/// \param img image in color space BGR
 	/// \return void
+	#[inline]
 	fn draw(&mut self, img: &mut dyn core::ToInputOutputArray) -> Result<()> {
 		input_output_array_arg!(img);
 		unsafe { sys::cv_mcc_CCheckerDraw_draw_const__InputOutputArrayR(self.as_raw_mut_MCC_CCheckerDraw(), img.as_raw__InputOutputArray()) }.into_result()
@@ -948,6 +991,7 @@ impl dyn MCC_CCheckerDraw + '_ {
 	/// ## C++ default parameters
 	/// * color: CV_RGB(0,250,0)
 	/// * thickness: 2
+	#[inline]
 	pub fn create(mut p_checker: core::Ptr<dyn crate::mcc::MCC_CChecker>, color: core::Scalar, thickness: i32) -> Result<core::Ptr<dyn crate::mcc::MCC_CCheckerDraw>> {
 		unsafe { sys::cv_mcc_CCheckerDraw_create_Ptr_CChecker__Scalar_int(p_checker.as_raw_mut_PtrOfMCC_CChecker(), color.opencv_as_extern(), thickness) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::mcc::MCC_CCheckerDraw>::opencv_from_extern(r) } )
 	}
@@ -1003,74 +1047,92 @@ impl dyn MCC_CCheckerDraw + '_ {
 pub trait MCC_DetectorParametersTraitConst {
 	fn as_raw_MCC_DetectorParameters(&self) -> *const c_void;
 
+	#[inline]
 	fn adaptive_thresh_win_size_min(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropAdaptiveThreshWinSizeMin_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: adaptive_thresh_win_size_min")
 	}
 	
+	#[inline]
 	fn adaptive_thresh_win_size_max(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropAdaptiveThreshWinSizeMax_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: adaptive_thresh_win_size_max")
 	}
 	
+	#[inline]
 	fn adaptive_thresh_win_size_step(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropAdaptiveThreshWinSizeStep_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: adaptive_thresh_win_size_step")
 	}
 	
+	#[inline]
 	fn adaptive_thresh_constant(&self) -> f64 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropAdaptiveThreshConstant_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: adaptive_thresh_constant")
 	}
 	
+	#[inline]
 	fn min_contours_area_rate(&self) -> f64 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinContoursAreaRate_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_contours_area_rate")
 	}
 	
+	#[inline]
 	fn min_contours_area(&self) -> f64 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinContoursArea_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_contours_area")
 	}
 	
+	#[inline]
 	fn confidence_threshold(&self) -> f64 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropConfidenceThreshold_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: confidence_threshold")
 	}
 	
+	#[inline]
 	fn min_contour_solidity(&self) -> f64 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinContourSolidity_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_contour_solidity")
 	}
 	
+	#[inline]
 	fn find_candidates_approx_poly_dp_eps_multiplier(&self) -> f64 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropFindCandidatesApproxPolyDPEpsMultiplier_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: find_candidates_approx_poly_dp_eps_multiplier")
 	}
 	
+	#[inline]
 	fn border_width(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropBorderWidth_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: border_width")
 	}
 	
+	#[inline]
 	fn b0factor(&self) -> f32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropB0factor_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: b0factor")
 	}
 	
+	#[inline]
 	fn max_error(&self) -> f32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMaxError_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: max_error")
 	}
 	
+	#[inline]
 	fn min_contour_points_allowed(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinContourPointsAllowed_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_contour_points_allowed")
 	}
 	
+	#[inline]
 	fn min_contour_length_allowed(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinContourLengthAllowed_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_contour_length_allowed")
 	}
 	
+	#[inline]
 	fn min_inter_contour_distance(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinInterContourDistance_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_inter_contour_distance")
 	}
 	
+	#[inline]
 	fn min_inter_checker_distance(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinInterCheckerDistance_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_inter_checker_distance")
 	}
 	
+	#[inline]
 	fn min_image_size(&self) -> i32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinImageSize_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_image_size")
 	}
 	
+	#[inline]
 	fn min_group_size(&self) -> u32 {
 		unsafe { sys::cv_mcc_DetectorParameters_getPropMinGroupSize_const(self.as_raw_MCC_DetectorParameters()) }.into_result().expect("Infallible function failed: min_group_size")
 	}
@@ -1080,75 +1142,93 @@ pub trait MCC_DetectorParametersTraitConst {
 pub trait MCC_DetectorParametersTrait: crate::mcc::MCC_DetectorParametersTraitConst {
 	fn as_raw_mut_MCC_DetectorParameters(&mut self) -> *mut c_void;
 
-	fn set_adaptive_thresh_win_size_min(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_adaptive_thresh_win_size_min(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropAdaptiveThreshWinSizeMin_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_adaptive_thresh_win_size_min")
 	}
 	
-	fn set_adaptive_thresh_win_size_max(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_adaptive_thresh_win_size_max(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropAdaptiveThreshWinSizeMax_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_adaptive_thresh_win_size_max")
 	}
 	
-	fn set_adaptive_thresh_win_size_step(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_adaptive_thresh_win_size_step(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropAdaptiveThreshWinSizeStep_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_adaptive_thresh_win_size_step")
 	}
 	
-	fn set_adaptive_thresh_constant(&mut self, val: f64) -> () {
+	#[inline]
+	fn set_adaptive_thresh_constant(&mut self, val: f64) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropAdaptiveThreshConstant_double(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_adaptive_thresh_constant")
 	}
 	
-	fn set_min_contours_area_rate(&mut self, val: f64) -> () {
+	#[inline]
+	fn set_min_contours_area_rate(&mut self, val: f64) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinContoursAreaRate_double(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_contours_area_rate")
 	}
 	
-	fn set_min_contours_area(&mut self, val: f64) -> () {
+	#[inline]
+	fn set_min_contours_area(&mut self, val: f64) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinContoursArea_double(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_contours_area")
 	}
 	
-	fn set_confidence_threshold(&mut self, val: f64) -> () {
+	#[inline]
+	fn set_confidence_threshold(&mut self, val: f64) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropConfidenceThreshold_double(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_confidence_threshold")
 	}
 	
-	fn set_min_contour_solidity(&mut self, val: f64) -> () {
+	#[inline]
+	fn set_min_contour_solidity(&mut self, val: f64) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinContourSolidity_double(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_contour_solidity")
 	}
 	
-	fn set_find_candidates_approx_poly_dp_eps_multiplier(&mut self, val: f64) -> () {
+	#[inline]
+	fn set_find_candidates_approx_poly_dp_eps_multiplier(&mut self, val: f64) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropFindCandidatesApproxPolyDPEpsMultiplier_double(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_find_candidates_approx_poly_dp_eps_multiplier")
 	}
 	
-	fn set_border_width(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_border_width(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropBorderWidth_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_border_width")
 	}
 	
-	fn set_b0factor(&mut self, val: f32) -> () {
+	#[inline]
+	fn set_b0factor(&mut self, val: f32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropB0factor_float(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_b0factor")
 	}
 	
-	fn set_max_error(&mut self, val: f32) -> () {
+	#[inline]
+	fn set_max_error(&mut self, val: f32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMaxError_float(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_max_error")
 	}
 	
-	fn set_min_contour_points_allowed(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_min_contour_points_allowed(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinContourPointsAllowed_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_contour_points_allowed")
 	}
 	
-	fn set_min_contour_length_allowed(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_min_contour_length_allowed(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinContourLengthAllowed_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_contour_length_allowed")
 	}
 	
-	fn set_min_inter_contour_distance(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_min_inter_contour_distance(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinInterContourDistance_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_inter_contour_distance")
 	}
 	
-	fn set_min_inter_checker_distance(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_min_inter_checker_distance(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinInterCheckerDistance_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_inter_checker_distance")
 	}
 	
-	fn set_min_image_size(&mut self, val: i32) -> () {
+	#[inline]
+	fn set_min_image_size(&mut self, val: i32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinImageSize_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_image_size")
 	}
 	
-	fn set_min_group_size(&mut self, val: u32) -> () {
+	#[inline]
+	fn set_min_group_size(&mut self, val: u32) {
 		unsafe { sys::cv_mcc_DetectorParameters_setPropMinGroupSize_unsigned_int(self.as_raw_mut_MCC_DetectorParameters(), val) }.into_result().expect("Infallible function failed: set_min_group_size")
 	}
 	
@@ -1225,10 +1305,12 @@ impl crate::mcc::MCC_DetectorParametersTrait for MCC_DetectorParameters {
 }
 
 impl MCC_DetectorParameters {
+	#[inline]
 	pub fn default() -> Result<crate::mcc::MCC_DetectorParameters> {
 		unsafe { sys::cv_mcc_DetectorParameters_DetectorParameters() }.into_result().map(|r| unsafe { crate::mcc::MCC_DetectorParameters::opencv_from_extern(r) } )
 	}
 	
+	#[inline]
 	pub fn create() -> Result<core::Ptr<crate::mcc::MCC_DetectorParameters>> {
 		unsafe { sys::cv_mcc_DetectorParameters_create() }.into_result().map(|r| unsafe { core::Ptr::<crate::mcc::MCC_DetectorParameters>::opencv_from_extern(r) } )
 	}
